import { type SelectProps } from '@chakra-ui/react';
import { type SystemStyleInterpolation } from '@chakra-ui/theme-tools';
type OptionType = Record<string, unknown>;
type OptionsType = Array<OptionType>;
type AutocompleteProps = {
    /** overrides to the base `autocompleteChakraStyles` */
    sx?: SystemStyleInterpolation;
    options: OptionsType;
    placeholder?: string;
    selectedOptionStyle?: string;
} & Pick<SelectProps, 'name' | 'size'> & {
    isMulti?: boolean;
    closeMenuOnSelect?: boolean;
    hasStickyGroupHeaders?: boolean;
    tagVariant?: string;
    chakraStyles?: Record<string, unknown>;
};
/**
 * Provides a react-select Autocomplete widget with Chakra fields
 *
 * - https://github.com/csandman/chakra-react-select
 * - https://react-select.com
 *
 * Note: under the hood, chakra-react-select imports from @chakra-ui/*
 * We are leveraging vite/rollup to rewrite these relevant imports to @burnsred/ui-chakra
 *
 * The minimum required is:
 * https://github.com/csandman/chakra-react-select/blob/main/src/use-chakra-select-props.ts#L2
 *
 * **Further rewrites may be required.**
 *
 * ## Styling
 *
 * > There are a few ways to style the components that make up
 * > chakra-react-select. It's important to note that this package does not use
 * > the theme or styles props that are implemented in react-select. The theme
 * > prop isn't used as most of the components' base styles are pulling from
 * > your Chakra theme, and customizing your base theme (such as colors or
 * > component styles) should in turn change the styles in this package.
 * >
 * > This package does however offer an alternative to the styles prop,
 * > [chakraStyles](https://github.com/csandman/chakra-react-select#chakrastyles).
 * > It mostly emulates the behavior of the original styles prop, however,
 * > because it’s not identical it is named differently to prevent confusion.
 *
 * https://github.com/csandman/chakra-react-select#styling
 *
 */
export declare const Autocomplete: ({ sx, ...props }: AutocompleteProps) => import("react/jsx-runtime").JSX.Element;
export {};
